# naowidgets

This projects contains:

 * General helpers for running NAOqi async calls in jupyter without locking, namely:
  * the @as_widget decorator
  * show

 * Dedicated widgets for arm control (one at a time or both together)

  ## Installation

You can install the package using pip:

```sh
pip install naowidgets
